/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as Flatfile from "../../../index";
export declare namespace Apps {
    interface Options {
        environment?: core.Supplier<environments.FlatfileEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        token?: core.Supplier<core.BearerToken | undefined>;
        /** Override the X-Disable-Hooks header */
        xDisableHooks?: "true";
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Override the X-Disable-Hooks header */
        xDisableHooks?: "true";
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
}
export declare class Apps {
    protected readonly _options: Apps.Options;
    constructor(_options?: Apps.Options);
    /**
     * Returns apps in an account
     *
     * @param {Apps.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.apps.list()
     */
    list(requestOptions?: Apps.RequestOptions): core.HttpResponsePromise<Flatfile.AppsResponse>;
    private __list;
    /**
     * Returns an app
     *
     * @param {Flatfile.AppId} appId - ID of app
     * @param {Apps.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.apps.get("us_app_YOUR_ID")
     */
    get(appId: Flatfile.AppId, requestOptions?: Apps.RequestOptions): core.HttpResponsePromise<Flatfile.AppResponse>;
    private __get;
    /**
     * Updates an app
     *
     * @param {Flatfile.AppId} appId - ID of app
     * @param {Flatfile.AppPatch} request
     * @param {Apps.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.apps.update("us_app_YOUR_ID", {
     *         name: "Nightly Data Loads",
     *         namespace: "nightly-data",
     *         entity: "Sync",
     *         entityPlural: "Syncs",
     *         icon: "<svg xmlns=\"http://www.w3.org/2000/svg\" fill=\"currentColor\" class=\"bi bi-bar-chart-fill\" viewBox=\"0 0 16 16\">\n  <path d=\"M1 11a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v3a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1zm5-4a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v7a1 1 0 0 1-1 1H7a1 1 0 0 1-1-1zm5-5a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1h-2a1 1 0 0 1-1-1z\"/>\n</svg>",
     *         metadata: {
     *             "foo": "bar"
     *         }
     *     })
     */
    update(appId: Flatfile.AppId, request: Flatfile.AppPatch, requestOptions?: Apps.RequestOptions): core.HttpResponsePromise<Flatfile.AppResponse>;
    private __update;
    /**
     * Creates an app
     *
     * @param {Flatfile.AppCreate} request
     * @param {Apps.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.apps.create({
     *         name: "Nightly Data Loads",
     *         namespace: "nightly-data",
     *         type: "CUSTOM",
     *         entity: "Sync",
     *         entityPlural: "Syncs",
     *         icon: "<svg xmlns=\"http://www.w3.org/2000/svg\" fill=\"currentColor\" class=\"bi bi-bar-chart-fill\" viewBox=\"0 0 16 16\">\n  <path d=\"M1 11a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v3a1 1 0 0 1-1 1H2a1 1 0 0 1-1-1zm5-4a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v7a1 1 0 0 1-1 1H7a1 1 0 0 1-1-1zm5-5a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v12a1 1 0 0 1-1 1h-2a1 1 0 0 1-1-1z\"/>\n</svg>",
     *         metadata: {
     *             "foo": "bar"
     *         }
     *     })
     */
    create(request: Flatfile.AppCreate, requestOptions?: Apps.RequestOptions): core.HttpResponsePromise<Flatfile.AppResponse>;
    private __create;
    /**
     * Deletes an app
     *
     * @param {Flatfile.AppId} appId - ID of app to delete
     * @param {Apps.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.apps.delete("us_app_YOUR_ID")
     */
    delete(appId: Flatfile.AppId, requestOptions?: Apps.RequestOptions): core.HttpResponsePromise<Flatfile.SuccessResponse>;
    private __delete;
    /**
     * Returns constraints for an app
     *
     * @param {Flatfile.AppId} appId - ID of the app
     * @param {Flatfile.GetConstraintsRequest} request
     * @param {Apps.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.apps.getConstraints("appId")
     */
    getConstraints(appId: Flatfile.AppId, request?: Flatfile.GetConstraintsRequest, requestOptions?: Apps.RequestOptions): core.HttpResponsePromise<Flatfile.ConstraintsResponse>;
    private __getConstraints;
    /**
     * Creates a new constraint for an app
     *
     * @param {Flatfile.AppId} appId - ID of the app
     * @param {Flatfile.ConstraintCreate} request
     * @param {Apps.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.apps.createConstraint("appId", {})
     */
    createConstraint(appId: Flatfile.AppId, request: Flatfile.ConstraintCreate, requestOptions?: Apps.RequestOptions): core.HttpResponsePromise<Flatfile.ConstraintResponse>;
    private __createConstraint;
    /**
     * Returns a specific constraint
     *
     * @param {Flatfile.AppId} appId - ID of the app
     * @param {Flatfile.ConstraintId} constraintId - ID of the constraint
     * @param {Apps.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.apps.getConstraintById("appId", "constraintId")
     */
    getConstraintById(appId: Flatfile.AppId, constraintId: Flatfile.ConstraintId, requestOptions?: Apps.RequestOptions): core.HttpResponsePromise<Flatfile.ConstraintResponse>;
    private __getConstraintById;
    /**
     * Returns the versions of a specific constraint
     *
     * @param {Flatfile.AppId} appId - ID of the app
     * @param {Flatfile.ConstraintId} constraintId - ID of the constraint
     * @param {Apps.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.apps.getConstraintVersions("appId", "constraintId")
     */
    getConstraintVersions(appId: Flatfile.AppId, constraintId: Flatfile.ConstraintId, requestOptions?: Apps.RequestOptions): core.HttpResponsePromise<Flatfile.ConstraintVersionsResponse>;
    private __getConstraintVersions;
    /**
     * Returns a specified version of a specific constraint
     *
     * @param {Flatfile.AppId} appId - ID of the app
     * @param {Flatfile.ConstraintId} constraintId - ID of the constraint
     * @param {number} version - Version of the constraint
     * @param {Apps.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.apps.getConstraintVersion("appId", "constraintId", 1)
     */
    getConstraintVersion(appId: Flatfile.AppId, constraintId: Flatfile.ConstraintId, version: number, requestOptions?: Apps.RequestOptions): core.HttpResponsePromise<Flatfile.ConstraintVersionResponse>;
    private __getConstraintVersion;
    /**
     * Updates a specific constraint
     *
     * @param {Flatfile.AppId} appId - ID of the app
     * @param {Flatfile.ConstraintId} constraintId - ID of the constraint
     * @param {Flatfile.ConstraintUpdate} request
     * @param {Apps.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.apps.updateConstraint("appId", "constraintId", {})
     */
    updateConstraint(appId: Flatfile.AppId, constraintId: Flatfile.ConstraintId, request: Flatfile.ConstraintUpdate, requestOptions?: Apps.RequestOptions): core.HttpResponsePromise<Flatfile.ConstraintResponse>;
    private __updateConstraint;
    /**
     * Deletes a specific constraint
     *
     * @param {Flatfile.AppId} appId - ID of the app
     * @param {Flatfile.ConstraintId} constraintId - ID of the constraint
     * @param {Apps.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.apps.deleteConstraint("appId", "constraintId")
     */
    deleteConstraint(appId: Flatfile.AppId, constraintId: Flatfile.ConstraintId, requestOptions?: Apps.RequestOptions): core.HttpResponsePromise<Flatfile.SuccessResponse>;
    private __deleteConstraint;
    protected _getAuthorizationHeader(): Promise<string | undefined>;
}
