/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as Flatfile from "../../../index";
export declare namespace CanvasAreas {
    interface Options {
        environment?: core.Supplier<environments.FlatfileEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        token?: core.Supplier<core.BearerToken | undefined>;
        /** Override the X-Disable-Hooks header */
        xDisableHooks?: "true";
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Override the X-Disable-Hooks header */
        xDisableHooks?: "true";
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
}
export declare class CanvasAreas {
    protected readonly _options: CanvasAreas.Options;
    constructor(_options?: CanvasAreas.Options);
    /**
     * Returns a list of canvas areas filtered by canvas, space, or environment
     *
     * @param {Flatfile.ListCanvasAreasRequest} request
     * @param {CanvasAreas.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     *
     * @example
     *     await client.canvasAreas.list()
     */
    list(request?: Flatfile.ListCanvasAreasRequest, requestOptions?: CanvasAreas.RequestOptions): core.HttpResponsePromise<Flatfile.ListCanvasAreasResponse>;
    private __list;
    /**
     * Creates a new canvas area
     *
     * @param {Flatfile.CreateCanvasAreaRequest} request
     * @param {CanvasAreas.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     *
     * @example
     *     await client.canvasAreas.create({
     *         canvasId: "canvasId",
     *         type: "mapping",
     *         position: "top"
     *     })
     */
    create(request: Flatfile.CreateCanvasAreaRequest, requestOptions?: CanvasAreas.RequestOptions): core.HttpResponsePromise<Flatfile.CanvasAreaResponse>;
    private __create;
    /**
     * Returns a specific canvas area by ID
     *
     * @param {Flatfile.CanvasAreaId} canvasAreaId
     * @param {CanvasAreas.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.canvasAreas.get("canvasAreaId")
     */
    get(canvasAreaId: Flatfile.CanvasAreaId, requestOptions?: CanvasAreas.RequestOptions): core.HttpResponsePromise<Flatfile.CanvasAreaResponse>;
    private __get;
    /**
     * Updates an existing canvas area
     *
     * @param {Flatfile.CanvasAreaId} canvasAreaId
     * @param {Flatfile.UpdateCanvasAreaRequest} request
     * @param {CanvasAreas.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.canvasAreas.update("canvasAreaId")
     */
    update(canvasAreaId: Flatfile.CanvasAreaId, request?: Flatfile.UpdateCanvasAreaRequest, requestOptions?: CanvasAreas.RequestOptions): core.HttpResponsePromise<Flatfile.CanvasAreaResponse>;
    private __update;
    /**
     * Deletes a specific canvas area
     *
     * @param {Flatfile.CanvasAreaId} canvasAreaId
     * @param {CanvasAreas.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.canvasAreas.delete("canvasAreaId")
     */
    delete(canvasAreaId: Flatfile.CanvasAreaId, requestOptions?: CanvasAreas.RequestOptions): core.HttpResponsePromise<Flatfile.Success>;
    private __delete;
    protected _getAuthorizationHeader(): Promise<string | undefined>;
}
