/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as Flatfile from "../../../index";
export declare namespace DataRetentionPolicies {
    interface Options {
        environment?: core.Supplier<environments.FlatfileEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        token?: core.Supplier<core.BearerToken | undefined>;
        /** Override the X-Disable-Hooks header */
        xDisableHooks?: "true";
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Override the X-Disable-Hooks header */
        xDisableHooks?: "true";
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
}
export declare class DataRetentionPolicies {
    protected readonly _options: DataRetentionPolicies.Options;
    constructor(_options?: DataRetentionPolicies.Options);
    /**
     * Returns all data retention policies on an account matching a filter for environmentId
     *
     * @param {Flatfile.ListDataRetentionPoliciesRequest} request
     * @param {DataRetentionPolicies.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.dataRetentionPolicies.list({
     *         environmentId: "us_env_YOUR_ID"
     *     })
     */
    list(request?: Flatfile.ListDataRetentionPoliciesRequest, requestOptions?: DataRetentionPolicies.RequestOptions): core.HttpResponsePromise<Flatfile.ListDataRetentionPoliciesResponse>;
    private __list;
    /**
     * Add a new data retention policy to the space
     *
     * @param {Flatfile.DataRetentionPolicyConfig} request
     * @param {DataRetentionPolicies.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.dataRetentionPolicies.create({
     *         type: "lastActivity",
     *         period: 5,
     *         environmentId: "us_env_YOUR_ID"
     *     })
     */
    create(request: Flatfile.DataRetentionPolicyConfig, requestOptions?: DataRetentionPolicies.RequestOptions): core.HttpResponsePromise<Flatfile.DataRetentionPolicyResponse>;
    private __create;
    /**
     * Returns a single data retention policy
     *
     * @param {Flatfile.DataRetentionPolicyId} id - ID of data retention policy to return
     * @param {DataRetentionPolicies.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.dataRetentionPolicies.get("us_drp_YOUR_ID")
     */
    get(id: Flatfile.DataRetentionPolicyId, requestOptions?: DataRetentionPolicies.RequestOptions): core.HttpResponsePromise<Flatfile.DataRetentionPolicyResponse>;
    private __get;
    /**
     * Updates a single data retention policy
     *
     * @param {Flatfile.DataRetentionPolicyId} id - ID of data retention policy to update
     * @param {Flatfile.DataRetentionPolicyConfig} request
     * @param {DataRetentionPolicies.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.dataRetentionPolicies.update("us_drp_YOUR_ID", {
     *         type: "lastActivity",
     *         period: 5,
     *         environmentId: "us_env_YOUR_ID"
     *     })
     */
    update(id: Flatfile.DataRetentionPolicyId, request: Flatfile.DataRetentionPolicyConfig, requestOptions?: DataRetentionPolicies.RequestOptions): core.HttpResponsePromise<Flatfile.DataRetentionPolicyResponse>;
    private __update;
    /**
     * Deletes a single data retention policy
     *
     * @param {Flatfile.DataRetentionPolicyId} id - ID of data retention policy to delete
     * @param {DataRetentionPolicies.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.dataRetentionPolicies.delete("id")
     */
    delete(id: Flatfile.DataRetentionPolicyId, requestOptions?: DataRetentionPolicies.RequestOptions): core.HttpResponsePromise<Flatfile.Success>;
    private __delete;
    protected _getAuthorizationHeader(): Promise<string | undefined>;
}
