/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as Flatfile from "../../../index";
export declare namespace Documents {
    interface Options {
        environment?: core.Supplier<environments.FlatfileEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        token?: core.Supplier<core.BearerToken | undefined>;
        /** Override the X-Disable-Hooks header */
        xDisableHooks?: "true";
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Override the X-Disable-Hooks header */
        xDisableHooks?: "true";
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
}
export declare class Documents {
    protected readonly _options: Documents.Options;
    constructor(_options?: Documents.Options);
    /**
     * Returns all documents for a space
     *
     * @param {Flatfile.SpaceId} spaceId - ID of space to return
     * @param {Documents.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.documents.list("us_sp_YOUR_ID")
     */
    list(spaceId: Flatfile.SpaceId, requestOptions?: Documents.RequestOptions): core.HttpResponsePromise<Flatfile.ListDocumentsResponse>;
    private __list;
    /**
     * Add a new document to the space
     *
     * @param {Flatfile.SpaceId} spaceId - ID of space to return
     * @param {Flatfile.DocumentConfig} request
     * @param {Documents.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.documents.create("us_sp_YOUR_ID", {
     *         title: "My Document 1",
     *         body: "My information",
     *         actions: [{
     *                 operation: "submitAction",
     *                 mode: "foreground",
     *                 label: "Submit",
     *                 description: "Submit data to webhook.site",
     *                 primary: true
     *             }]
     *     })
     */
    create(spaceId: Flatfile.SpaceId, request: Flatfile.DocumentConfig, requestOptions?: Documents.RequestOptions): core.HttpResponsePromise<Flatfile.DocumentResponse>;
    private __create;
    /**
     * Returns a single document
     *
     * @param {Flatfile.SpaceId} spaceId - ID of space to return
     * @param {Flatfile.DocumentId} documentId - ID of document to return
     * @param {Documents.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.documents.get("us_sp_YOUR_ID", "us_dc_YOUR_ID")
     */
    get(spaceId: Flatfile.SpaceId, documentId: Flatfile.DocumentId, requestOptions?: Documents.RequestOptions): core.HttpResponsePromise<Flatfile.DocumentResponse>;
    private __get;
    /**
     * updates a single document, for only the body and title
     *
     * @param {Flatfile.SpaceId} spaceId - ID of space to return
     * @param {Flatfile.DocumentId} documentId - ID of document to return
     * @param {Flatfile.DocumentConfig} request
     * @param {Documents.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.documents.update("us_sp_YOUR_ID", "us_dc_YOUR_ID", {
     *         title: "Updated Title",
     *         body: "Updated My information"
     *     })
     */
    update(spaceId: Flatfile.SpaceId, documentId: Flatfile.DocumentId, request: Flatfile.DocumentConfig, requestOptions?: Documents.RequestOptions): core.HttpResponsePromise<Flatfile.DocumentResponse>;
    private __update;
    /**
     * Deletes a single document
     *
     * @param {Flatfile.SpaceId} spaceId - ID of space to return
     * @param {Flatfile.DocumentId} documentId - ID of document to delete
     * @param {Documents.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.documents.delete("spaceId", "documentId")
     */
    delete(spaceId: Flatfile.SpaceId, documentId: Flatfile.DocumentId, requestOptions?: Documents.RequestOptions): core.HttpResponsePromise<Flatfile.Success>;
    private __delete;
    protected _getAuthorizationHeader(): Promise<string | undefined>;
}
