/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as Flatfile from "../../../index";
export declare namespace Guests {
    interface Options {
        environment?: core.Supplier<environments.FlatfileEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        token?: core.Supplier<core.BearerToken | undefined>;
        /** Override the X-Disable-Hooks header */
        xDisableHooks?: "true";
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Override the X-Disable-Hooks header */
        xDisableHooks?: "true";
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
}
export declare class Guests {
    protected readonly _options: Guests.Options;
    constructor(_options?: Guests.Options);
    /**
     * Returns all guests
     *
     * @param {Flatfile.ListGuestsRequest} request
     * @param {Guests.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.guests.list({
     *         spaceId: "us_sp_YOUR_ID"
     *     })
     */
    list(request: Flatfile.ListGuestsRequest, requestOptions?: Guests.RequestOptions): core.HttpResponsePromise<Flatfile.ListGuestsResponse>;
    private __list;
    /**
     * Guests are only there to upload, edit, and download files and perform their tasks in a specific Space.
     *
     * @param {Flatfile.GuestConfig[]} request
     * @param {Guests.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.guests.create([{
     *             environmentId: "us_env_YOUR_ID",
     *             email: "email@example.com",
     *             name: "Your Name",
     *             spaces: [{
     *                     id: "us_sp_YOUR_ID",
     *                     workbooks: [{
     *                             id: "us_wb_YOUR_ID"
     *                         }],
     *                     sheets: [{
     *                             id: "us_sh_YOUR_ID"
     *                         }],
     *                     lastAccessed: "2023-10-30T16:59:45.735Z"
     *                 }]
     *         }])
     */
    create(request: Flatfile.GuestConfig[], requestOptions?: Guests.RequestOptions): core.HttpResponsePromise<Flatfile.CreateGuestResponse>;
    private __create;
    /**
     * Returns a single guest
     *
     * @param {Flatfile.GuestId} guestId - ID of guest to return
     * @param {Guests.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.guests.get("us_g_YOUR_ID")
     */
    get(guestId: Flatfile.GuestId, requestOptions?: Guests.RequestOptions): core.HttpResponsePromise<Flatfile.GuestResponse>;
    private __get;
    /**
     * Deletes a single guest
     *
     * @param {Flatfile.GuestId} guestId - ID of guest to return
     * @param {Guests.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.guests.delete("us_g_YOUR_ID")
     */
    delete(guestId: Flatfile.GuestId, requestOptions?: Guests.RequestOptions): core.HttpResponsePromise<Flatfile.Success>;
    private __delete;
    /**
     * Updates a single guest, for example to change name or email
     *
     * @param {Flatfile.GuestId} guestId - ID of guest to return
     * @param {Flatfile.GuestConfigUpdate} request
     * @param {Guests.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.guests.update("us_g_YOUR_ID", {
     *         email: "updated@example.com",
     *         name: "Your Name Updated"
     *     })
     */
    update(guestId: Flatfile.GuestId, request: Flatfile.GuestConfigUpdate, requestOptions?: Guests.RequestOptions): core.HttpResponsePromise<Flatfile.GuestResponse>;
    private __update;
    /**
     * Returns a single guest token
     *
     * @param {Flatfile.GuestId} guestId - ID of guest to return
     * @param {Flatfile.GetGuestTokenRequest} request
     * @param {Guests.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.guests.getGuestToken("us_g_YOUR_ID")
     */
    getGuestToken(guestId: Flatfile.GuestId, request?: Flatfile.GetGuestTokenRequest, requestOptions?: Guests.RequestOptions): core.HttpResponsePromise<Flatfile.GuestTokenResponse>;
    private __getGuestToken;
    /**
     * Lists roles assigned to a guest.
     *
     * @param {Flatfile.GuestId} guestId - The guest id
     * @param {Guests.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     * @throws {@link Flatfile.ForbiddenError}
     *
     * @example
     *     await client.guests.listGuestRoles("guestId")
     */
    listGuestRoles(guestId: Flatfile.GuestId, requestOptions?: Guests.RequestOptions): core.HttpResponsePromise<Flatfile.ListActorRolesResponse>;
    private __listGuestRoles;
    /**
     * Assigns a role to a guest.
     *
     * @param {Flatfile.GuestId} guestId - The guest id
     * @param {Flatfile.AssignActorRoleRequest} request
     * @param {Guests.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     * @throws {@link Flatfile.ForbiddenError}
     *
     * @example
     *     await client.guests.assignGuestRole("guestId", {
     *         roleId: "roleId",
     *         resourceId: "resourceId"
     *     })
     */
    assignGuestRole(guestId: Flatfile.GuestId, request: Flatfile.AssignActorRoleRequest, requestOptions?: Guests.RequestOptions): core.HttpResponsePromise<Flatfile.AssignRoleResponse>;
    private __assignGuestRole;
    /**
     * Removes a role from a guest.
     *
     * @param {Flatfile.GuestId} guestId - The guest id
     * @param {Flatfile.ActorRoleId} actorRoleId - The actor role id
     * @param {Guests.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     * @throws {@link Flatfile.ForbiddenError}
     *
     * @example
     *     await client.guests.deleteGuestRole("guestId", "actorRoleId")
     */
    deleteGuestRole(guestId: Flatfile.GuestId, actorRoleId: Flatfile.ActorRoleId, requestOptions?: Guests.RequestOptions): core.HttpResponsePromise<Flatfile.Success>;
    private __deleteGuestRole;
    /**
     * Guests can be created as a named guest on the Space or there’s a global link that will let anonymous guests into the space.
     *
     * @param {Flatfile.Invite[]} request
     * @param {Guests.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.guests.invite([{
     *             guestId: "us_g_YOUR_ID",
     *             spaceId: "us_sp_YOUR_ID",
     *             fromName: "Your Name",
     *             message: "Hello, I would like to invite you to my space."
     *         }])
     */
    invite(request: Flatfile.Invite[], requestOptions?: Guests.RequestOptions): core.HttpResponsePromise<Flatfile.Success>;
    private __invite;
    protected _getAuthorizationHeader(): Promise<string | undefined>;
}
