/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as Flatfile from "../../../index";
export declare namespace Messages {
    interface Options {
        environment?: core.Supplier<environments.FlatfileEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        token?: core.Supplier<core.BearerToken | undefined>;
        /** Override the X-Disable-Hooks header */
        xDisableHooks?: "true";
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Override the X-Disable-Hooks header */
        xDisableHooks?: "true";
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
}
export declare class Messages {
    protected readonly _options: Messages.Options;
    constructor(_options?: Messages.Options);
    /**
     * Create a new message in a thread
     *
     * @param {Flatfile.ThreadId} threadId
     * @param {Flatfile.MessageApiCreateData} request
     * @param {Messages.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     * @throws {@link Flatfile.ForbiddenError}
     *
     * @example
     *     await client.messages.createMessage("threadId", {
     *         content: {
     *             "content": {
     *                 "key": "value"
     *             }
     *         },
     *         role: "system"
     *     })
     */
    createMessage(threadId: Flatfile.ThreadId, request: Flatfile.MessageApiCreateData, requestOptions?: Messages.RequestOptions): core.HttpResponsePromise<Flatfile.MessageModel>;
    private __createMessage;
    /**
     * Get all messages in a thread
     *
     * @param {Flatfile.ThreadId} threadId
     * @param {Messages.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.NotFoundError}
     * @throws {@link Flatfile.ForbiddenError}
     *
     * @example
     *     await client.messages.getMessages("threadId")
     */
    getMessages(threadId: Flatfile.ThreadId, requestOptions?: Messages.RequestOptions): core.HttpResponsePromise<Flatfile.MessageCollection>;
    private __getMessages;
    /**
     * Get a specific message by ID
     *
     * @param {Flatfile.ThreadId} threadId
     * @param {Flatfile.MessageId} messageId
     * @param {Messages.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.NotFoundError}
     * @throws {@link Flatfile.ForbiddenError}
     *
     * @example
     *     await client.messages.getMessage("threadId", "messageId")
     */
    getMessage(threadId: Flatfile.ThreadId, messageId: Flatfile.MessageId, requestOptions?: Messages.RequestOptions): core.HttpResponsePromise<Flatfile.MessageModel>;
    private __getMessage;
    /**
     * Update an existing message
     *
     * @param {Flatfile.ThreadId} threadId
     * @param {Flatfile.MessageId} messageId
     * @param {Flatfile.MessageApiUpdateData} request
     * @param {Messages.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     * @throws {@link Flatfile.ForbiddenError}
     *
     * @example
     *     await client.messages.updateMessage("threadId", "messageId", {})
     */
    updateMessage(threadId: Flatfile.ThreadId, messageId: Flatfile.MessageId, request: Flatfile.MessageApiUpdateData, requestOptions?: Messages.RequestOptions): core.HttpResponsePromise<Flatfile.MessageModel>;
    private __updateMessage;
    /**
     * Delete a message
     *
     * @param {Flatfile.ThreadId} threadId
     * @param {Flatfile.MessageId} messageId
     * @param {Messages.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.NotFoundError}
     * @throws {@link Flatfile.ForbiddenError}
     *
     * @example
     *     await client.messages.deleteMessage("threadId", "messageId")
     */
    deleteMessage(threadId: Flatfile.ThreadId, messageId: Flatfile.MessageId, requestOptions?: Messages.RequestOptions): core.HttpResponsePromise<Flatfile.Success>;
    private __deleteMessage;
    protected _getAuthorizationHeader(): Promise<string | undefined>;
}
