/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as Flatfile from "../../../index";
export declare namespace Onboardings {
    interface Options {
        environment?: core.Supplier<environments.FlatfileEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        token?: core.Supplier<core.BearerToken | undefined>;
        /** Override the X-Disable-Hooks header */
        xDisableHooks?: "true";
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Override the X-Disable-Hooks header */
        xDisableHooks?: "true";
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
}
export declare class Onboardings {
    protected readonly _options: Onboardings.Options;
    constructor(_options?: Onboardings.Options);
    /**
     * Create a new onboarding
     *
     * @param {Flatfile.OnboardingCreate} request
     * @param {Onboardings.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     * @throws {@link Flatfile.ForbiddenError}
     *
     * @example
     *     await client.onboardings.createOnboarding({
     *         userId: "userId"
     *     })
     */
    createOnboarding(request: Flatfile.OnboardingCreate, requestOptions?: Onboardings.RequestOptions): core.HttpResponsePromise<Flatfile.OnboardingResponse>;
    private __createOnboarding;
    /**
     * Get onboardings with optional filtering by user ID
     *
     * @param {Flatfile.GetOnboardingsRequest} request
     * @param {Onboardings.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.ForbiddenError}
     *
     * @example
     *     await client.onboardings.getOnboardings()
     */
    getOnboardings(request?: Flatfile.GetOnboardingsRequest, requestOptions?: Onboardings.RequestOptions): core.HttpResponsePromise<Flatfile.OnboardingsResponse>;
    private __getOnboardings;
    /**
     * Get a single onboarding by ID
     *
     * @param {Flatfile.OnboardingId} onboardingId
     * @param {Onboardings.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.NotFoundError}
     * @throws {@link Flatfile.ForbiddenError}
     *
     * @example
     *     await client.onboardings.getOnboarding("onboardingId")
     */
    getOnboarding(onboardingId: Flatfile.OnboardingId, requestOptions?: Onboardings.RequestOptions): core.HttpResponsePromise<Flatfile.OnboardingResponse>;
    private __getOnboarding;
    /**
     * Soft delete an onboarding
     *
     * @param {Flatfile.OnboardingId} onboardingId
     * @param {Onboardings.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.NotFoundError}
     * @throws {@link Flatfile.ForbiddenError}
     *
     * @example
     *     await client.onboardings.deleteOnboarding("onboardingId")
     */
    deleteOnboarding(onboardingId: Flatfile.OnboardingId, requestOptions?: Onboardings.RequestOptions): core.HttpResponsePromise<Flatfile.Success>;
    private __deleteOnboarding;
    protected _getAuthorizationHeader(): Promise<string | undefined>;
}
