/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as Flatfile from "../../../index";
export declare namespace Runbooks {
    interface Options {
        environment?: core.Supplier<environments.FlatfileEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        token?: core.Supplier<core.BearerToken | undefined>;
        /** Override the X-Disable-Hooks header */
        xDisableHooks?: "true";
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Override the X-Disable-Hooks header */
        xDisableHooks?: "true";
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
}
export declare class Runbooks {
    protected readonly _options: Runbooks.Options;
    constructor(_options?: Runbooks.Options);
    /**
     * Returns a list of runbooks
     *
     * @param {Flatfile.ListRunbooksRequest} request
     * @param {Runbooks.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.runbooks.list()
     */
    list(request?: Flatfile.ListRunbooksRequest, requestOptions?: Runbooks.RequestOptions): core.HttpResponsePromise<Flatfile.RunbooksResponse>;
    private __list;
    /**
     * Returns a runbook
     *
     * @param {Flatfile.RunbookId} runbookId
     * @param {Runbooks.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.runbooks.get("us_rb_YOUR_ID")
     */
    get(runbookId: Flatfile.RunbookId, requestOptions?: Runbooks.RequestOptions): core.HttpResponsePromise<Flatfile.RunbookResponse>;
    private __get;
    /**
     * Creates a new runbook
     *
     * @param {Flatfile.CreateRunbookRequest} request
     * @param {Runbooks.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.runbooks.create({
     *         accountId: "us_acc_YOUR_ID",
     *         appId: "us_app_YOUR_ID",
     *         environmentId: "us_env_YOUR_ID",
     *         spaceId: "us_sp_YOUR_ID",
     *         name: "Runbook For Vendor X",
     *         config: {
     *             sourceSheetIds: ["us_sh_YOUR_ID"],
     *             destinationSheetIds: ["us_sh_YOUR_ID"]
     *         },
     *         status: "CREATED",
     *         type: "PREPROCESSING"
     *     })
     */
    create(request: Flatfile.CreateRunbookRequest, requestOptions?: Runbooks.RequestOptions): core.HttpResponsePromise<Flatfile.RunbookResponse>;
    private __create;
    /**
     * Updates a runbook
     *
     * @param {Flatfile.RunbookId} runbookId
     * @param {Flatfile.UpdateRunbookRequest} request
     * @param {Runbooks.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.runbooks.update("us_rb_YOUR_ID", {
     *         name: "Runbook For Vendor X"
     *     })
     */
    update(runbookId: Flatfile.RunbookId, request: Flatfile.UpdateRunbookRequest, requestOptions?: Runbooks.RequestOptions): core.HttpResponsePromise<Flatfile.RunbookResponse>;
    private __update;
    /**
     * Deletes a runbook
     *
     * @param {Flatfile.RunbookId} runbookId
     * @param {Runbooks.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.runbooks.delete("us_rb_YOUR_ID")
     */
    delete(runbookId: Flatfile.RunbookId, requestOptions?: Runbooks.RequestOptions): core.HttpResponsePromise<Flatfile.Success>;
    private __delete;
    protected _getAuthorizationHeader(): Promise<string | undefined>;
}
