/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as Flatfile from "../../../index";
export declare namespace Jobs {
    interface Options {
        environment?: core.Supplier<environments.FlatfileEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        token?: core.Supplier<core.BearerToken | undefined>;
        /** Override the X-Disable-Hooks header */
        xDisableHooks?: "true";
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Override the X-Disable-Hooks header */
        xDisableHooks?: "true";
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
}
export declare class Jobs {
    protected readonly _options: Jobs.Options;
    constructor(_options?: Jobs.Options);
    /**
     * @param {Flatfile.ListJobsRequest} request
     * @param {Jobs.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.jobs.list({
     *         environmentId: "us_env_YOUR_ID",
     *         spaceId: "us_sp_YOUR_ID"
     *     })
     */
    list(request?: Flatfile.ListJobsRequest, requestOptions?: Jobs.RequestOptions): core.HttpResponsePromise<Flatfile.ListJobsResponse>;
    private __list;
    /**
     * @param {Flatfile.JobConfig} request
     * @param {Jobs.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.jobs.create({
     *         type: "workbook",
     *         operation: "submitAction",
     *         source: "us_wb_YOUR_ID"
     *     })
     */
    create(request: Flatfile.JobConfig, requestOptions?: Jobs.RequestOptions): core.HttpResponsePromise<Flatfile.JobResponse>;
    private __create;
    /**
     * @param {Flatfile.JobId} jobId - The id of the job to return
     * @param {Jobs.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.jobs.get("us_jb_YOUR_ID")
     */
    get(jobId: Flatfile.JobId, requestOptions?: Jobs.RequestOptions): core.HttpResponsePromise<Flatfile.JobResponse>;
    private __get;
    /**
     * @param {Flatfile.JobId} jobId - The id of the job to patch
     * @param {Flatfile.JobUpdate} request
     * @param {Jobs.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.jobs.update("us_jb_YOUR_ID", {
     *         config: {},
     *         status: "complete",
     *         progress: 100
     *     })
     */
    update(jobId: Flatfile.JobId, request: Flatfile.JobUpdate, requestOptions?: Jobs.RequestOptions): core.HttpResponsePromise<Flatfile.JobResponse>;
    private __update;
    /**
     * @param {Flatfile.JobId} jobId - The id of the job to delete
     * @param {Jobs.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.jobs.delete("us_jb_YOUR_ID")
     */
    delete(jobId: Flatfile.JobId, requestOptions?: Jobs.RequestOptions): core.HttpResponsePromise<Flatfile.Success>;
    private __delete;
    /**
     * Execute a job and return the job
     *
     * @param {string} jobId - ID of job to return
     * @param {Jobs.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.jobs.execute("us_jb_YOUR_ID")
     */
    execute(jobId: string, requestOptions?: Jobs.RequestOptions): core.HttpResponsePromise<Flatfile.Success>;
    private __execute;
    /**
     * Returns a single job's execution plan
     *
     * @param {Flatfile.JobId} jobId - ID of job to return
     * @param {Jobs.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.jobs.getExecutionPlan("us_jb_YOUR_ID")
     */
    getExecutionPlan(jobId: Flatfile.JobId, requestOptions?: Jobs.RequestOptions): core.HttpResponsePromise<Flatfile.JobPlanResponse>;
    private __getExecutionPlan;
    /**
     * Update a job's entire execution plan
     *
     * @param {Flatfile.JobId} jobId - ID of job to return
     * @param {Flatfile.JobExecutionPlanRequest} request
     * @param {Jobs.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.jobs.updateExecutionPlan("us_jb_YOUR_ID", {
     *         fieldMapping: [{
     *                 sourceField: {
     *                     type: "string",
     *                     key: "firstName"
     *                 },
     *                 destinationField: {
     *                     type: "string",
     *                     key: "firstName",
     *                     label: "First Name"
     *                 }
     *             }, {
     *                 sourceField: {
     *                     type: "string",
     *                     key: "lastName"
     *                 },
     *                 destinationField: {
     *                     type: "string",
     *                     key: "lastName",
     *                     label: "Last Name"
     *                 }
     *             }],
     *         unmappedSourceFields: [{
     *                 sourceField: {
     *                     type: "string",
     *                     key: "email"
     *                 }
     *             }],
     *         unmappedDestinationFields: [{
     *                 destinationField: {
     *                     type: "string",
     *                     key: "email",
     *                     label: "Email"
     *                 }
     *             }],
     *         fileId: "us_fl_YOUR_ID",
     *         jobId: "us_jb_YOUR_ID"
     *     })
     */
    updateExecutionPlan(jobId: Flatfile.JobId, request: Flatfile.JobExecutionPlanRequest, requestOptions?: Jobs.RequestOptions): core.HttpResponsePromise<Flatfile.JobPlanResponse>;
    private __updateExecutionPlan;
    /**
     * Update one or more individual fields on a job's execution plan
     *
     * @param {string} jobId - ID of job to return
     * @param {Flatfile.JobExecutionPlanConfigRequest} request
     * @param {Jobs.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.jobs.updateExecutionPlanFields("jobId", {
     *         fileId: "fileId",
     *         jobId: "jobId"
     *     })
     */
    updateExecutionPlanFields(jobId: string, request: Flatfile.JobExecutionPlanConfigRequest, requestOptions?: Jobs.RequestOptions): core.HttpResponsePromise<Flatfile.JobPlanResponse>;
    private __updateExecutionPlanFields;
    /**
     * Acknowledge a job and return the job
     *
     * @param {Flatfile.JobId} jobId - ID of job to return
     * @param {Flatfile.JobAckDetails} request
     * @param {Jobs.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.jobs.ack("us_jb_YOUR_ID", {
     *         info: "Acknowledged by user",
     *         progress: 100,
     *         estimatedCompletionAt: "2023-10-30T20:04:32.074Z"
     *     })
     */
    ack(jobId: Flatfile.JobId, request?: Flatfile.JobAckDetails, requestOptions?: Jobs.RequestOptions): core.HttpResponsePromise<Flatfile.JobResponse>;
    private __ack;
    /**
     * Acknowledge a job outcome and return the job
     *
     * @param {Flatfile.JobId} jobId - ID of job to return
     * @param {Jobs.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.jobs.ackOutcome("us_jb_YOUR_ID")
     */
    ackOutcome(jobId: Flatfile.JobId, requestOptions?: Jobs.RequestOptions): core.HttpResponsePromise<Flatfile.JobResponse>;
    private __ackOutcome;
    /**
     * Complete a job and return the job
     *
     * @param {Flatfile.JobId} jobId - ID of job to return
     * @param {Flatfile.JobCompleteDetails} request
     * @param {Jobs.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.jobs.complete("us_jb_YOUR_ID", {
     *         outcome: {
     *             acknowledge: true,
     *             buttonText: "Acknowledge",
     *             next: {
     *                 type: "id",
     *                 id: "us_jb_YOUR_ID"
     *             },
     *             heading: "Success",
     *             message: "Job was successful"
     *         },
     *         info: "Job is Complete"
     *     })
     */
    complete(jobId: Flatfile.JobId, request?: Flatfile.JobCompleteDetails, requestOptions?: Jobs.RequestOptions): core.HttpResponsePromise<Flatfile.JobResponse>;
    private __complete;
    /**
     * Fail a job and return the job
     *
     * @param {Flatfile.JobId} jobId - ID of job to return
     * @param {Flatfile.JobCompleteDetails} request
     * @param {Jobs.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.jobs.fail("us_jb_YOUR_ID", {
     *         outcome: {
     *             acknowledge: true,
     *             buttonText: "Acknowledge",
     *             next: {
     *                 type: "id",
     *                 id: "us_jb_YOUR_ID"
     *             },
     *             heading: "Failed",
     *             message: "Job failed"
     *         },
     *         info: "Job was failed"
     *     })
     */
    fail(jobId: Flatfile.JobId, request?: Flatfile.JobCompleteDetails, requestOptions?: Jobs.RequestOptions): core.HttpResponsePromise<Flatfile.JobResponse>;
    private __fail;
    /**
     * Cancel a job and return the job
     *
     * @param {Flatfile.JobId} jobId - ID of job to return
     * @param {Flatfile.JobCancelDetails} request
     * @param {Jobs.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.jobs.cancel("us_jb_YOUR_ID", {
     *         info: "Job was canceled"
     *     })
     */
    cancel(jobId: Flatfile.JobId, request?: Flatfile.JobCancelDetails, requestOptions?: Jobs.RequestOptions): core.HttpResponsePromise<Flatfile.JobResponse>;
    private __cancel;
    /**
     * Retry a failt job and return the job
     *
     * @param {Flatfile.JobId} jobId - ID of job to return
     * @param {Jobs.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.jobs.retry("jobId")
     */
    retry(jobId: Flatfile.JobId, requestOptions?: Jobs.RequestOptions): core.HttpResponsePromise<Flatfile.JobResponse>;
    private __retry;
    /**
     * Preview the results of a mutation
     *
     * @param {Flatfile.MutateJobConfig} request
     * @param {Jobs.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.jobs.previewMutation({
     *         sheetId: "sheetId",
     *         mutateRecord: "mutateRecord"
     *     })
     */
    previewMutation(request: Flatfile.MutateJobConfig, requestOptions?: Jobs.RequestOptions): core.HttpResponsePromise<Flatfile.DiffRecordsResponse>;
    private __previewMutation;
    /**
     * Split a job and return the job
     *
     * @param {Flatfile.JobId} jobId - ID of job to return
     * @param {Flatfile.JobSplitDetails} request
     * @param {Jobs.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.jobs.split("us_jb_YOUR_ID", {
     *         parts: [{}],
     *         runInParallel: true
     *     })
     */
    split(jobId: Flatfile.JobId, request: Flatfile.JobSplitDetails, requestOptions?: Jobs.RequestOptions): core.HttpResponsePromise<Flatfile.JobResponse>;
    private __split;
    protected _getAuthorizationHeader(): Promise<string | undefined>;
}
