/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as Flatfile from "../../../index";
export declare namespace OnboardingDatapoints {
    interface Options {
        environment?: core.Supplier<environments.FlatfileEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        token?: core.Supplier<core.BearerToken | undefined>;
        /** Override the X-Disable-Hooks header */
        xDisableHooks?: "true";
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Override the X-Disable-Hooks header */
        xDisableHooks?: "true";
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
}
export declare class OnboardingDatapoints {
    protected readonly _options: OnboardingDatapoints.Options;
    constructor(_options?: OnboardingDatapoints.Options);
    /**
     * Create a new onboarding datapoint
     *
     * @param {Flatfile.OnboardingId} onboardingId
     * @param {Flatfile.OnboardingDatapointCreate} request
     * @param {OnboardingDatapoints.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     * @throws {@link Flatfile.ForbiddenError}
     *
     * @example
     *     await client.onboardingDatapoints.createOnboardingDatapoint("onboardingId", {
     *         onboardingId: "onboardingId",
     *         data: {
     *             "key": "value"
     *         }
     *     })
     */
    createOnboardingDatapoint(onboardingId: Flatfile.OnboardingId, request: Flatfile.OnboardingDatapointCreate, requestOptions?: OnboardingDatapoints.RequestOptions): core.HttpResponsePromise<Flatfile.OnboardingDatapointResponse>;
    private __createOnboardingDatapoint;
    /**
     * Get all datapoints for an onboarding
     *
     * @param {Flatfile.OnboardingId} onboardingId
     * @param {OnboardingDatapoints.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.ForbiddenError}
     *
     * @example
     *     await client.onboardingDatapoints.getOnboardingDatapoints("onboardingId")
     */
    getOnboardingDatapoints(onboardingId: Flatfile.OnboardingId, requestOptions?: OnboardingDatapoints.RequestOptions): core.HttpResponsePromise<Flatfile.OnboardingDatapointsResponse>;
    private __getOnboardingDatapoints;
    /**
     * Get a single onboarding datapoint by ID
     *
     * @param {Flatfile.OnboardingId} onboardingId
     * @param {Flatfile.OnboardingDatapointId} datapointId
     * @param {OnboardingDatapoints.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.NotFoundError}
     * @throws {@link Flatfile.ForbiddenError}
     *
     * @example
     *     await client.onboardingDatapoints.getOnboardingDatapoint("onboardingId", "datapointId")
     */
    getOnboardingDatapoint(onboardingId: Flatfile.OnboardingId, datapointId: Flatfile.OnboardingDatapointId, requestOptions?: OnboardingDatapoints.RequestOptions): core.HttpResponsePromise<Flatfile.OnboardingDatapointResponse>;
    private __getOnboardingDatapoint;
    /**
     * Update an onboarding datapoint
     *
     * @param {Flatfile.OnboardingId} onboardingId
     * @param {Flatfile.OnboardingDatapointId} datapointId
     * @param {Flatfile.OnboardingDatapointUpdate} request
     * @param {OnboardingDatapoints.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     * @throws {@link Flatfile.ForbiddenError}
     *
     * @example
     *     await client.onboardingDatapoints.updateOnboardingDatapoint("onboardingId", "datapointId", {})
     */
    updateOnboardingDatapoint(onboardingId: Flatfile.OnboardingId, datapointId: Flatfile.OnboardingDatapointId, request: Flatfile.OnboardingDatapointUpdate, requestOptions?: OnboardingDatapoints.RequestOptions): core.HttpResponsePromise<Flatfile.OnboardingDatapointResponse>;
    private __updateOnboardingDatapoint;
    /**
     * Soft delete an onboarding datapoint
     *
     * @param {Flatfile.OnboardingId} onboardingId
     * @param {Flatfile.OnboardingDatapointId} datapointId
     * @param {OnboardingDatapoints.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.NotFoundError}
     * @throws {@link Flatfile.ForbiddenError}
     *
     * @example
     *     await client.onboardingDatapoints.deleteOnboardingDatapoint("onboardingId", "datapointId")
     */
    deleteOnboardingDatapoint(onboardingId: Flatfile.OnboardingId, datapointId: Flatfile.OnboardingDatapointId, requestOptions?: OnboardingDatapoints.RequestOptions): core.HttpResponsePromise<Flatfile.Success>;
    private __deleteOnboardingDatapoint;
    protected _getAuthorizationHeader(): Promise<string | undefined>;
}
