/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as Flatfile from "../../../index";
export declare namespace Routines {
    interface Options {
        environment?: core.Supplier<environments.FlatfileEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        token?: core.Supplier<core.BearerToken | undefined>;
        /** Override the X-Disable-Hooks header */
        xDisableHooks?: "true";
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Override the X-Disable-Hooks header */
        xDisableHooks?: "true";
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
}
export declare class Routines {
    protected readonly _options: Routines.Options;
    constructor(_options?: Routines.Options);
    /**
     * Returns a list of routines
     *
     * @param {Flatfile.ListRoutinesRequest} request
     * @param {Routines.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.routines.list({
     *         runbookId: "us_rb_YOUR_ID"
     *     })
     */
    list(request: Flatfile.ListRoutinesRequest, requestOptions?: Routines.RequestOptions): core.HttpResponsePromise<Flatfile.RoutinesResponse>;
    private __list;
    /**
     * Returns a routine
     *
     * @param {Flatfile.RoutineId} routineId
     * @param {Routines.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.routines.get("us_rtn_YOUR_ID")
     */
    get(routineId: Flatfile.RoutineId, requestOptions?: Routines.RequestOptions): core.HttpResponsePromise<Flatfile.RoutineResponse>;
    private __get;
    /**
     * Creates a new routine
     *
     * @param {Flatfile.CreateRoutineRequest} request
     * @param {Routines.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.routines.create({
     *         runbookId: "us_rb_YOUR_ID",
     *         name: "Split Address to Street, City, State, Zip",
     *         config: {
     *             "sourceSheetId": "us_sh_YOUR_ID",
     *             "destinationSheetId": "us_sh_YOUR_ID",
     *             "programId": "us_mp_YOUR_ID"
     *         },
     *         ordinal: 1,
     *         type: "JOB"
     *     })
     */
    create(request: Flatfile.CreateRoutineRequest, requestOptions?: Routines.RequestOptions): core.HttpResponsePromise<Flatfile.RoutineResponse>;
    private __create;
    /**
     * Updates a routine
     *
     * @param {Flatfile.RoutineId} routineId
     * @param {Flatfile.UpdateRoutineRequest} request
     * @param {Routines.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.routines.update("us_rtn_YOUR_ID", {
     *         name: "Split Address to Street, City, State, Zip",
     *         config: {
     *             "sourceSheetId": "us_sh_YOUR_ID",
     *             "destinationSheetId": "us_sh_YOUR_ID",
     *             "programId": "us_mp_YOUR_ID"
     *         },
     *         ordinal: 1,
     *         type: "JOB"
     *     })
     */
    update(routineId: Flatfile.RoutineId, request: Flatfile.UpdateRoutineRequest, requestOptions?: Routines.RequestOptions): core.HttpResponsePromise<Flatfile.RoutineResponse>;
    private __update;
    /**
     * Deletes a routine
     *
     * @param {Flatfile.RoutineId} routineId
     * @param {Routines.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.routines.delete("us_rtn_YOUR_ID")
     */
    delete(routineId: Flatfile.RoutineId, requestOptions?: Routines.RequestOptions): core.HttpResponsePromise<Flatfile.Success>;
    private __delete;
    protected _getAuthorizationHeader(): Promise<string | undefined>;
}
