/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as Flatfile from "../../../index";
export declare namespace Workbooks {
    interface Options {
        environment?: core.Supplier<environments.FlatfileEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        token?: core.Supplier<core.BearerToken | undefined>;
        /** Override the X-Disable-Hooks header */
        xDisableHooks?: "true";
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Override the X-Disable-Hooks header */
        xDisableHooks?: "true";
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
}
export declare class Workbooks {
    protected readonly _options: Workbooks.Options;
    constructor(_options?: Workbooks.Options);
    /**
     * Returns all workbooks matching a filter for an account or space
     *
     * @param {Flatfile.ListWorkbooksRequest} request
     * @param {Workbooks.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     *
     * @example
     *     await client.workbooks.list({
     *         spaceId: "us_sp_YOUR_ID"
     *     })
     */
    list(request?: Flatfile.ListWorkbooksRequest, requestOptions?: Workbooks.RequestOptions): core.HttpResponsePromise<Flatfile.ListWorkbooksResponse>;
    private __list;
    /**
     * Creates a workbook and adds it to a space
     *
     * @param {Flatfile.CreateWorkbookConfig} request
     * @param {Workbooks.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     *
     * @example
     *     await client.workbooks.create({
     *         name: "My First Workbook",
     *         sheets: [{
     *                 name: "Contacts",
     *                 slug: "contacts",
     *                 fields: [{
     *                         type: "string",
     *                         key: "firstName",
     *                         label: "First Name"
     *                     }, {
     *                         type: "string",
     *                         key: "lastName",
     *                         label: "Last Name"
     *                     }, {
     *                         type: "string",
     *                         key: "email",
     *                         label: "Email"
     *                     }],
     *                 mappingConfidenceThreshold: 0.5
     *             }],
     *         labels: ["simple-demo"],
     *         actions: [{
     *                 operation: "submitAction",
     *                 mode: "foreground",
     *                 label: "Submit",
     *                 description: "Submit data to webhook.site",
     *                 primary: true
     *             }],
     *         settings: {
     *             trackChanges: true
     *         }
     *     })
     */
    create(request: Flatfile.CreateWorkbookConfig, requestOptions?: Workbooks.RequestOptions): core.HttpResponsePromise<Flatfile.WorkbookResponse>;
    private __create;
    /**
     * Returns a single workbook
     *
     * @param {Flatfile.WorkbookId} workbookId - ID of workbook to return
     * @param {Workbooks.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.workbooks.get("us_wb_YOUR_ID")
     */
    get(workbookId: Flatfile.WorkbookId, requestOptions?: Workbooks.RequestOptions): core.HttpResponsePromise<Flatfile.WorkbookResponse>;
    private __get;
    /**
     * Deletes a workbook and all of its record data permanently
     *
     * @param {Flatfile.WorkbookId} workbookId - ID of workbook to delete
     * @param {Workbooks.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.workbooks.delete("us_wb_YOUR_ID")
     */
    delete(workbookId: Flatfile.WorkbookId, requestOptions?: Workbooks.RequestOptions): core.HttpResponsePromise<Flatfile.Success>;
    private __delete;
    /**
     * Updates a workbook
     * <Note>
     *   Adding a sheet to a workbook does not require the config object to be provided, however updating an existing sheet does.
     * </Note>
     *
     * @param {Flatfile.WorkbookId} workbookId - ID of workbook to update
     * @param {Flatfile.WorkbookUpdate} request
     * @param {Workbooks.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.workbooks.update("us_wb_YOUR_ID", {
     *         name: "My Updated Workbook",
     *         labels: ["my-new-label"],
     *         actions: [{
     *                 operation: "submitAction",
     *                 mode: "foreground",
     *                 label: "Submit Changes",
     *                 description: "Submit data to webhook.site",
     *                 primary: true
     *             }]
     *     })
     */
    update(workbookId: Flatfile.WorkbookId, request: Flatfile.WorkbookUpdate, requestOptions?: Workbooks.RequestOptions): core.HttpResponsePromise<Flatfile.WorkbookResponse>;
    private __update;
    /**
     * Returns the commits for a workbook
     *
     * @param {Flatfile.WorkbookId} workbookId - ID of workbook
     * @param {Flatfile.ListWorkbookCommitsRequest} request
     * @param {Workbooks.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.workbooks.getWorkbookCommits("us_wb_YOUR_ID")
     */
    getWorkbookCommits(workbookId: Flatfile.WorkbookId, request?: Flatfile.ListWorkbookCommitsRequest, requestOptions?: Workbooks.RequestOptions): core.HttpResponsePromise<Flatfile.ListCommitsResponse>;
    private __getWorkbookCommits;
    /**
     * Rebuild a workbook
     *
     * @param {Flatfile.WorkbookId} workbookId - ID of workbook to rebuild
     * @param {Workbooks.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.workbooks.rebuildWorkbook("workbookId")
     */
    rebuildWorkbook(workbookId: Flatfile.WorkbookId, requestOptions?: Workbooks.RequestOptions): core.HttpResponsePromise<Flatfile.Success>;
    private __rebuildWorkbook;
    protected _getAuthorizationHeader(): Promise<string | undefined>;
}
