import { Flatfile } from "..";
import { Records as FernRecords } from "../api/resources/records/client/Client";
import * as core from "../core";
interface InsertRequestOptions extends FernRecords.RequestOptions {
    compressRequestBody?: boolean;
}
export declare class Records extends FernRecords {
    /**
     * Adds records to a workbook sheet
     *
     * @param {Flatfile.SheetId} sheetId - ID of sheet
     * @param {Flatfile.RecordData[]} request
     * @param {Records.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Flatfile.BadRequestError}
     * @throws {@link Flatfile.NotFoundError}
     *
     * @example
     *     await client.records.insert("us_sh_YOUR_ID", [{
     *             "firstName": {
     *                 value: "John",
     *                 messages: [],
     *                 valid: true
     *             },
     *             "lastName": {
     *                 value: "Smith",
     *                 messages: [],
     *                 valid: true
     *             },
     *             "email": {
     *                 value: "john.smith@example.com",
     *                 messages: [],
     *                 valid: true
     *             }
     *         }])
     */
    insert(sheetId: Flatfile.SheetId, request: Flatfile.RecordData[], requestOptions?: InsertRequestOptions): core.HttpResponsePromise<Flatfile.RecordsResponse>;
    private __insertRecords;
}
export {};
